@@ -247,9 +247,9 @@ class PrintSettingsToolbox(QToolBox):
 
             if utils.which('lpr'):
                 if alt_nup:
-                    cmd = ' '.join(['psnup', '-%d' % nup, ''.join(['"', p, '"']), '| lpr -P', self.cur_printer])
+                    cmd = ' '.join(['psnup', '-%d' % nup, ''.join(['"', p, '"']), '| /usr/local/bin/lpr -P', self.cur_printer])
                 else:
-                    cmd = ' '.join(['lpr -P', self.cur_printer])
+                    cmd = ' '.join(['/usr/local/bin/lpr -P', self.cur_printer])
 
                 if copies > 1:
                     cmd = ' '.join([cmd, '-#%d' % copies])
